@@ -1,196 +1,211 @@
 context("AbbreviationPipe")
 
 test_that("initialize",{
-
+  skip_if_not_installed("rjson")
+  skip_if_not_installed("rex")
+  skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
   notAfterDeps <- list()
 
-  Bdpar$new(configurationFilePath = system.file("configurations",
-                                                "test_pipeline_execute_tsms_configurations.ini",
-                                                package = "bdpar"))
+  Bdpar$new(configurationFilePath = file.path("testFiles",
+                                              "testAbbreviationPipe",
+                                              "configurations.ini"))
 
   expect_silent(AbbreviationPipe$new(propertyName, propertyLanguageName, alwaysBeforeDeps, notAfterDeps))
 })
 
 test_that("initialize propertyName type error",{
-
+  skip_if_not_installed("rex")
+  skip_if_not_installed("textutils")
   propertyName <- NULL
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
   notAfterDeps <- list()
 
-  expect_error(AbbreviationPipe$new(propertyName, propertyLanguageName, alwaysBeforeDeps, notAfterDeps),"\\[AbbreviationPipe\\]\\[initialize\\]\\[Error\\]
+  expect_error(AbbreviationPipe$new(propertyName, propertyLanguageName, alwaysBeforeDeps, notAfterDeps), "\\[AbbreviationPipe\\]\\[initialize\\]\\[Error\\]
                 Checking the type of the variable: propertyName NULL")
 })
 
 test_that("initialize propertyLanguageName type error",{
-
+  skip_if_not_installed("rex")
+  skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- NULL
   alwaysBeforeDeps <- list()
   notAfterDeps <- list()
 
-  expect_error(AbbreviationPipe$new(propertyName, propertyLanguageName, alwaysBeforeDeps, notAfterDeps),"\\[AbbreviationPipe\\]\\[initialize\\]\\[Error\\]
+  expect_error(AbbreviationPipe$new(propertyName, propertyLanguageName, alwaysBeforeDeps, notAfterDeps), "\\[AbbreviationPipe\\]\\[initialize\\]\\[Error\\]
                 Checking the type of the variable: propertyLanguageName NULL")
 })
 
 test_that("initialize alwaysBeforeDeps type error",{
-
+  skip_if_not_installed("rex")
+  skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- NULL
   notAfterDeps <- list()
 
-  expect_error(AbbreviationPipe$new(propertyName, propertyLanguageName, alwaysBeforeDeps ,notAfterDeps),"\\[AbbreviationPipe\\]\\[initialize\\]\\[Error\\]
+  expect_error(AbbreviationPipe$new(propertyName, propertyLanguageName, alwaysBeforeDeps ,notAfterDeps), "\\[AbbreviationPipe\\]\\[initialize\\]\\[Error\\]
                 Checking the type of the variable: alwaysBeforeDeps NULL")
 })
 
 test_that("initialize notAfterDeps type error",{
-
+  skip_if_not_installed("rex")
+  skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
   notAfterDeps <- NULL
 
-  expect_error(AbbreviationPipe$new(propertyName, propertyLanguageName, alwaysBeforeDeps ,notAfterDeps),"\\[AbbreviationPipe\\]\\[initialize\\]\\[Error\\]
+  expect_error(AbbreviationPipe$new(propertyName, propertyLanguageName, alwaysBeforeDeps, notAfterDeps), "\\[AbbreviationPipe\\]\\[initialize\\]\\[Error\\]
                 Checking the type of the variable: notAfterDeps NULL")
-
 })
 
 test_that("pipe",{
-
+  skip_if_not_installed("rjson")
+  skip_if_not_installed("rex")
+  skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
   notAfterDeps <- list()
 
-  Bdpar$new(configurationFilePath = system.file("configurations",
-                                                "test_pipeline_execute_tsms_configurations.ini",
-                                                package = "bdpar"))
+  Bdpar$new(configurationFilePath = file.path("testFiles",
+                                              "testAbbreviationPipe",
+                                              "configurations.ini"))
 
   pipe <- AbbreviationPipe$new(propertyName, propertyLanguageName, alwaysBeforeDeps ,notAfterDeps)
 
-  path <- system.file(file.path("testFiles","_ham_",
-                                "30.tsms"),
-                      package = "bdpar")
+  path <- file.path("testFiles",
+                    "testAbbreviationPipe",
+                    "testFile.tsms")
 
   instance <- ExtractorSms$new(path)
   instance$setData("Admin. something")
   instance$addProperties("en","language")
   replaceAbbreviations <- TRUE
 
-  path <- system.file(file.path("testResources",
-                                "abbreviations-json"),
-                      package = "bdpar")
+  path <- file.path("resourcesFiles",
+                    "testResources",
+                    "abbreviations-json")
 
   pipe$setResourcesAbbreviationsPath(path)
   instance <- pipe$pipe(instance, replaceAbbreviations)
 
-  expect_equal(instance$getSpecificProperty("abbreviation"),"Admin.")
+  expect_equal(instance$getSpecificProperty("abbreviation"), "Admin.")
 
 })
 
 test_that("pipe data empty",{
-
+  skip_if_not_installed("rjson")
+  skip_if_not_installed("rex")
+  skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
   notAfterDeps <- list()
 
-  Bdpar$new(configurationFilePath = system.file("configurations",
-                                                "test_pipeline_execute_tsms_configurations.ini",
-                                                package = "bdpar"))
+  Bdpar$new(configurationFilePath = file.path("testFiles",
+                                              "testAbbreviationPipe",
+                                              "configurations.ini"))
 
   pipe <- AbbreviationPipe$new(propertyName, propertyLanguageName, alwaysBeforeDeps ,notAfterDeps)
 
-  path <- system.file(file.path("testFiles","_ham_",
-                                "30.tsms"),
-                      package = "bdpar")
+  path <- file.path("testFiles",
+                    "testAbbreviationPipe",
+                    "testFile.tsms")
 
   instance <- ExtractorSms$new(path)
   instance$setData("")
   instance$addProperties("en","language")
   replaceAbbreviations <- TRUE
 
-  path <- system.file(file.path("testResources",
-                                "abbreviations-json"),
-                      package = "bdpar")
+  path <- file.path("resourcesFiles",
+                    "testResources",
+                    "abbreviations-json")
 
   pipe$setResourcesAbbreviationsPath(path)
 
-  expect_warning(pipe$pipe(instance, replaceAbbreviations),"\\[AbbreviationPipe\\]\\[pipe\\]\\[Warning\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/_ham_\\/30\\.tsms has data empty on pipe Abbreviation ")
+  expect_warning(pipe$pipe(instance, replaceAbbreviations),"\\[AbbreviationPipe\\]\\[pipe\\]\\[Warning\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/testAbbreviationPipe\\/testFile\\.tsms has data empty on pipe Abbreviation ")
 
 })
 
 test_that("pipe wihtout json file",{
-
+  skip_if_not_installed("rjson")
+  skip_if_not_installed("rex")
+  skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
   notAfterDeps <- list()
 
-  Bdpar$new(configurationFilePath = system.file("configurations",
-                                                "test_pipeline_execute_tsms_configurations.ini",
-                                                package = "bdpar"))
+  Bdpar$new(configurationFilePath = file.path("testFiles",
+                                              "testAbbreviationPipe",
+                                              "configurations.ini"))
 
   pipe <- AbbreviationPipe$new(propertyName, propertyLanguageName, alwaysBeforeDeps ,notAfterDeps)
 
-  path <- system.file(file.path("testFiles","_ham_",
-                                "30.tsms"),
-                      package = "bdpar")
+  path <- file.path("testFiles",
+                    "testAbbreviationPipe",
+                    "testFile.tsms")
 
   instance <- ExtractorSms$new(path)
   instance$setData("D. something")
   instance$addProperties("en","language")
   replaceAbbreviations <- TRUE
 
-  expect_warning(pipe$pipe(instance, replaceAbbreviations),"\\[AbbreviationPipe\\]\\[pipe\\]\\[Warning\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/_ham_\\/30\\.tsms has not an abbreviationsJsonFile to apply to the language ->en ")
+  expect_warning(pipe$pipe(instance, replaceAbbreviations),"\\[AbbreviationPipe\\]\\[pipe\\]\\[Warning\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/testAbbreviationPipe\\/testFile\\.tsms has not an abbreviationsJsonFile to apply to the language ->en ")
 
 })
 
 test_that("pipe wihtout language property",{
-
+  skip_if_not_installed("rjson")
+  skip_if_not_installed("rex")
+  skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
   notAfterDeps <- list()
 
-  Bdpar$new(configurationFilePath = system.file("configurations",
-                                                "test_pipeline_execute_tsms_configurations.ini",
-                                                package = "bdpar"))
+  Bdpar$new(configurationFilePath = file.path("testFiles",
+                                              "testAbbreviationPipe",
+                                              "configurations.ini"))
 
   pipe <- AbbreviationPipe$new(propertyName, propertyLanguageName, alwaysBeforeDeps ,notAfterDeps)
 
-  path <- system.file(file.path("testFiles","_ham_",
-                                "30.tsms"),
-                      package = "bdpar")
+  path <- file.path("testFiles",
+                    "testAbbreviationPipe",
+                    "testFile.tsms")
 
   instance <- ExtractorSms$new(path)
   instance$setData("D. something")
   replaceAbbreviations <- TRUE
 
-  expect_warning(pipe$pipe(instance, replaceAbbreviations),"\\[AbbreviationPipe\\]\\[pipe\\]\\[Warning\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/_ham_\\/30\\.tsms has not language property")
+  expect_warning(pipe$pipe(instance, replaceAbbreviations),"\\[AbbreviationPipe\\]\\[pipe\\]\\[Warning\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/testAbbreviationPipe\\/testFile\\.tsms has not language property")
 
 })
 
 test_that("pipe Bad compatibility between Pipes.",{
-
+  skip_if_not_installed("rjson")
+  skip_if_not_installed("rex")
+  skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list("pipeExample")
   notAfterDeps <- list()
 
-  Bdpar$new(configurationFilePath = system.file("configurations",
-                                                "test_pipeline_execute_tsms_configurations.ini",
-                                                package = "bdpar"))
+  Bdpar$new(configurationFilePath = file.path("testFiles",
+                                              "testAbbreviationPipe",
+                                              "configurations.ini"))
 
   pipe <- AbbreviationPipe$new(propertyName, propertyLanguageName, alwaysBeforeDeps ,notAfterDeps)
 
-  path <- system.file(file.path("testFiles","_ham_",
-                                "30.tsms"),
-                      package = "bdpar")
+  path <- file.path("testFiles",
+                    "testAbbreviationPipe",
+                    "testFile.tsms")
 
   instance <- ExtractorSms$new(path)
   instance$addBanPipes("pipeExample")
@@ -201,15 +216,17 @@ test_that("pipe Bad compatibility between Pipes.",{
 })
 
 test_that("pipe instance type error",{
-
+  skip_if_not_installed("rjson")
+  skip_if_not_installed("rex")
+  skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
   notAfterDeps <- list()
 
-  Bdpar$new(configurationFilePath = system.file("configurations",
-                                                "test_pipeline_execute_tsms_configurations.ini",
-                                                package = "bdpar"))
+  Bdpar$new(configurationFilePath = file.path("testFiles",
+                                              "testAbbreviationPipe",
+                                              "configurations.ini"))
 
   pipe <- AbbreviationPipe$new(propertyName, propertyLanguageName, alwaysBeforeDeps ,notAfterDeps)
 
@@ -222,20 +239,23 @@ test_that("pipe instance type error",{
 })
 
 test_that("pipe replaceAbbreviations type error",{
-
+  skip_if_not_installed("rjson")
+  skip_if_not_installed("rex")
+  skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
   notAfterDeps <- list()
 
-  Bdpar$new(configurationFilePath = system.file("configurations",
-                                                "test_pipeline_execute_tsms_configurations.ini",
-                                                package = "bdpar"))
+  Bdpar$new(configurationFilePath = file.path("testFiles",
+                                              "testAbbreviationPipe",
+                                              "configurations.ini"))
+
   pipe <- AbbreviationPipe$new(propertyName, propertyLanguageName, alwaysBeforeDeps ,notAfterDeps)
 
-  path <- system.file(file.path("testFiles","_ham_",
-                                "30.tsms"),
-                      package = "bdpar")
+  path <- file.path("testFiles",
+                    "testAbbreviationPipe",
+                    "testFile.tsms")
 
   instance <- ExtractorSms$new(path)
   instance$setData("D. something")
@@ -246,11 +266,18 @@ test_that("pipe replaceAbbreviations type error",{
 })
 
 test_that("findAbbreviation",{
-
+  skip_if_not_installed("rex")
+  skip_if_not_installed("rjson")
+  skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
   notAfterDeps <- list()
+
+  Bdpar$new(configurationFilePath = file.path("testFiles",
+                                              "testAbbreviationPipe",
+                                              "configurations.ini"))
+
   pipe <- AbbreviationPipe$new(propertyName, propertyLanguageName, alwaysBeforeDeps, notAfterDeps)
 
   abbreviation <- "D."
@@ -261,11 +288,16 @@ test_that("findAbbreviation",{
 })
 
 test_that("findAbbreviation abbreviation type error",{
-
+  skip_if_not_installed("rjson")
+  skip_if_not_installed("rex")
+  skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
   notAfterDeps <- list()
+  Bdpar$new(configurationFilePath = file.path("testFiles",
+                                              "testAbbreviationPipe",
+                                              "configurations.ini"))
   pipe <- AbbreviationPipe$new(propertyName, propertyLanguageName, alwaysBeforeDeps, notAfterDeps)
 
   abbreviation <- NULL
@@ -273,14 +305,20 @@ test_that("findAbbreviation abbreviation type error",{
 
   expect_error(pipe$findAbbreviation(data, abbreviation),"\\[AbbreviationPipe\\]\\[findAbbreviation\\]\\[Error\\]
                 Checking the type of the variable: abbreviation NULL")
+
 })
 
 test_that("findAbbreviation data type error",{
-
+  skip_if_not_installed("rjson")
+  skip_if_not_installed("rex")
+  skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
   notAfterDeps <- list()
+  Bdpar$new(configurationFilePath = file.path("testFiles",
+                                              "testAbbreviationPipe",
+                                              "configurations.ini"))
   pipe <- AbbreviationPipe$new(propertyName, propertyLanguageName, alwaysBeforeDeps, notAfterDeps)
 
   abbreviation <- "D."
@@ -291,11 +329,16 @@ test_that("findAbbreviation data type error",{
 })
 
 test_that("replaceAbbreviation ",{
-
+  skip_if_not_installed("rjson")
+  skip_if_not_installed("rex")
+  skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
   notAfterDeps <- list()
+  Bdpar$new(configurationFilePath = file.path("testFiles",
+                                              "testAbbreviationPipe",
+                                              "configurations.ini"))
   pipe <- AbbreviationPipe$new(propertyName, propertyLanguageName, alwaysBeforeDeps, notAfterDeps)
 
   abbreviation <- "D."
@@ -307,11 +350,16 @@ test_that("replaceAbbreviation ",{
 })
 
 test_that("replaceAbbreviation abbreviation type error",{
-
+  skip_if_not_installed("rjson")
+  skip_if_not_installed("rex")
+  skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
   notAfterDeps <- list()
+  Bdpar$new(configurationFilePath = file.path("testFiles",
+                                              "testAbbreviationPipe",
+                                              "configurations.ini"))
   pipe <- AbbreviationPipe$new(propertyName, propertyLanguageName, alwaysBeforeDeps, notAfterDeps)
 
   abbreviation <- NULL
@@ -324,11 +372,16 @@ test_that("replaceAbbreviation abbreviation type error",{
 })
 
 test_that("replaceAbbreviation extendedAbbreviation type error",{
-
+  skip_if_not_installed("rjson")
+  skip_if_not_installed("rex")
+  skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
   notAfterDeps <- list()
+  Bdpar$new(configurationFilePath = file.path("testFiles",
+                                              "testAbbreviationPipe",
+                                              "configurations.ini"))
   pipe <- AbbreviationPipe$new(propertyName, propertyLanguageName, alwaysBeforeDeps, notAfterDeps)
 
   abbreviation <- "D."
@@ -341,11 +394,16 @@ test_that("replaceAbbreviation extendedAbbreviation type error",{
 })
 
 test_that("replaceAbbreviation data type error",{
-
+  skip_if_not_installed("rjson")
+  skip_if_not_installed("rex")
+  skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
   notAfterDeps <- list()
+  Bdpar$new(configurationFilePath = file.path("testFiles",
+                                              "testAbbreviationPipe",
+                                              "configurations.ini"))
   pipe <- AbbreviationPipe$new(propertyName, propertyLanguageName, alwaysBeforeDeps, notAfterDeps)
 
   abbreviation <- "D."
@@ -358,16 +416,17 @@ test_that("replaceAbbreviation data type error",{
 })
 
 test_that("getPropertyLanguageName",{
-
+  skip_if_not_installed("rjson")
+  skip_if_not_installed("rex")
+  skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
   notAfterDeps <- list()
 
-  Bdpar$new(configurationFilePath = system.file("configurations",
-                                                "test_pipeline_execute_tsms_configurations.ini",
-                                                package = "bdpar"))
-
+  Bdpar$new(configurationFilePath = file.path("testFiles",
+                                              "testAbbreviationPipe",
+                                              "configurations.ini"))
   pipe <- AbbreviationPipe$new(propertyName, propertyLanguageName, alwaysBeforeDeps ,notAfterDeps)
 
   expect_equal(pipe$getPropertyLanguageName(), "language")
@@ -375,22 +434,24 @@ test_that("getPropertyLanguageName",{
 })
 
 test_that("getResourcesAbbreviationsPath",{
-
+  skip_if_not_installed("rjson")
+  skip_if_not_installed("rex")
+  skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
   notAfterDeps <- list()
 
-  Bdpar$new(configurationFilePath = system.file("configurations",
-                                                "test_pipeline_execute_tsms_configurations.ini",
-                                                package = "bdpar"))
+  Bdpar$new(configurationFilePath = file.path("testFiles",
+                                              "testAbbreviationPipe",
+                                              "configurations.ini"))
 
   pipe <- AbbreviationPipe$new(propertyName, propertyLanguageName, alwaysBeforeDeps ,notAfterDeps)
 
-  path <- system.file(file.path("testResources",
-                                        "abbreviations-json",
-                                        "abbrev.en.json"),
-                              package = "bdpar")
+  path <- file.path("resourcesFiles",
+                    "testResources",
+                    "abbreviations-json",
+                    "abbrev.en.json")
 
   pipe$setResourcesAbbreviationsPath(path)
 
@@ -399,22 +460,24 @@ test_that("getResourcesAbbreviationsPath",{
 })
 
 test_that("setResourcesAbbreviationsPath",{
-
+  skip_if_not_installed("rjson")
+  skip_if_not_installed("rex")
+  skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
   notAfterDeps <- list()
 
-  Bdpar$new(configurationFilePath = system.file("configurations",
-                                                "test_pipeline_execute_tsms_configurations.ini",
-                                                package = "bdpar"))
+  Bdpar$new(configurationFilePath = file.path("testFiles",
+                                              "testAbbreviationPipe",
+                                              "configurations.ini"))
 
   pipe <- AbbreviationPipe$new(propertyName, propertyLanguageName, alwaysBeforeDeps ,notAfterDeps)
 
-  path <- system.file(file.path("testResources",
-                                "abbreviations-json",
-                                "abbrev.en.json"),
-                      package = "bdpar")
+  path <- file.path("resourcesFiles",
+                    "testResources",
+                    "abbreviations-json",
+                    "abbrev.en.json")
 
   pipe$setResourcesAbbreviationsPath(path)
 
@@ -423,15 +486,17 @@ test_that("setResourcesAbbreviationsPath",{
 })
 
 test_that("setResourcesAbbreviationsPath path type error",{
-
+  skip_if_not_installed("rjson")
+  skip_if_not_installed("rex")
+  skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
   notAfterDeps <- list()
 
-  Bdpar$new(configurationFilePath = system.file("configurations",
-                                                "test_pipeline_execute_tsms_configurations.ini",
-                                                package = "bdpar"))
+  Bdpar$new(configurationFilePath = file.path("testFiles",
+                                              "testAbbreviationPipe",
+                                              "configurations.ini"))
 
   pipe <- AbbreviationPipe$new(propertyName, propertyLanguageName, alwaysBeforeDeps ,notAfterDeps)
 
